http_security_pinning library

Classes

HttpSecurityPinningClient
An implementation of Dart's HttpClient that enforces certificate pinning.

Exceptions / Errors

CertificateFetchException
Thrown when fetching the certificate chain from the native platform fails.
CertificatePinningException
The base class for all exceptions thrown by the http_security_pinning package.
NoValidPinsFoundException
Thrown when the server's certificate chain is successfully fetched, but none of the certificates' SPKI hashes match the pins provided to the client.