CertificateFetchException class

Thrown when fetching the certificate chain from the native platform fails.

This can happen due to network errors, timeouts, or if the native code encounters an unexpected issue. The message property contains more details from the native layer.

Inheritance

Constructors

CertificateFetchException(String message)
Creates a new certificate fetch exception.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
A descriptive message explaining the error.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited