NoValidPinsFoundException class

Thrown when the server's certificate chain is successfully fetched, but none of the certificates' SPKI hashes match the pins provided to the client.

This is the primary exception that indicates a pinning validation failure.

Inheritance

Constructors

NoValidPinsFoundException(String host)
Creates a new "no valid pins found" exception.

Properties

hashCode int
The hash code for this object.
no setterinherited
host String
The host for which the pinning validation failed.
final
message String
A descriptive message explaining the error.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited